==> hlw-core-0.0.2-20250418.054021-7-sources.jar: cn/gtmap/hlw/core/model/GxYySqxxHtxx.java <==
package cn.gtmap.hlw.core.model;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;


/**
 * (GxYySqxxHtxx)表实体类BO
 *
 * @author makejava
 * @since 2023-05-31 14:14:45
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class GxYySqxxHtxx implements Serializable {
    private static final long serialVersionUID = 7664420771347555104L;
    /**申请id*/
    private String sqid;

    /**受理编号*/
    private String slbh;

    /**交易价格*/
    private Double jyjg;

    /**付款方式*/
    private String fkfs;

    /**首付款*/
    private Double sfk;

    /**贷款种类*/
    private String dkzl;

    /**申请贷款*/
    private Double sqdk;

    /**是否通过代理*/
    private String sftgdl;

    /**是否进行资金监管*/
    private String sfzjjg;

    /**监管金额*/
    private Double jgje;

    /**交付方式*/
    private String jffs;

    private String jfqx;

    /**税费承担*/
    private String sfcd;

    /**付款截至日期（YYYY-MM-DD）*/
    private String fkjzrq;

    private String htqdrq;

    /**是否普通住房（0 否 1 是 ）*/
    private String sfptzf;

    /**合同金额*/
    private Double htje;

    /**单价*/
    private Double dj;

    /**交易方式代码*/
    private String jyfsdm;

    /**房屋交付日期（YYYY-MM-DD)*/
    private String fwjfrq;

    /**不动产项目名称*/
    private String xmmc;

    /**备案日期*/
    private String barq;

    /**定金*/
    private String yhdj;

    /**商贷金额*/
    private String yhsdje;

    /**公积金贷款金额*/
    private String yhgjjdkje;

    /**合同总额*/
    private Double htze;

    /**备案状态代码（1：已备案0：未备案）*/
    private String baztdm;

    /**成交价是否含税   0 否 1 是*/
    private String cjjsfhs;

    /**房产证发证时间*/
    private String fczfzsj;

    /**上次交易登记时间*/
    private String scjydjsj;

    /**不含增值税金额*/
    private Double bhzzsje;

    /**含增值税金额*/
    private Double hzzsje;

    /**增值税金额*/
    private Double zzsje;

    /**交易份额*/
    private Double jyfe;

    /**监管编号*/
    private String jgbh;

    /**合同坐落*/
    private String htzl;

    /**合同义务人名称*/
    private String htywrmc;

    /**其他约定事项*/
    private String qtydsx;

    /**贷款银行*/
    private String dkyh;

    /**合同约定登记时间*/
    private String htyddjsj;

    /**人才劵金额*/
    private String rcqje;

    /**违约金金额*/
    private String wyjje;

    /**产籍号*/
    private String fccjh;

    /**房地产交易时间（YYYY-MM-DD）*/
    private String fdcjysj;

    /**签约类型（0：线上签订 1：线下签订）*/
    private String qylx;

    /**是否签署（0：无合同 1：有合同）*/
    private String sfqs;

    /**是否交房即发证（1：是，0：否）*/
    private String sfjfjfz;

    /**交房即发证备注*/
    private String jfjfzbz;

    /**交易合同id（交易返回htid）*/
    private String jyhtid;

    /**自付款金额（单位：元）*/
    private Double zfkje;

    /**其他款项金额（单位：元）*/
    private Double qtkxje;

    /**付款金额（单位：元）*/
    private Double fkje;

    /**付款期数*/
    private Integer fkqs;

    /**约定登记日期*/
    private String yddjrq;

    /**土地处理方式（zd_type表对照）*/
    private String tdclfs;

    /**土地处理方式其他*/
    private String tdclfsjqt;

    /**税费约定方式（zd_type表对照）*/
    private String sfydfs;

    /**佣金约定方式（zd_type表对照）*/
    private String yjydfs;

    /**争议解决方式（zd_type表对照）*/
    private String zyjjfs;

    /**合同份数*/
    private Integer htfs;

    /**卖方合同份数*/
    private Integer salerhtfs;

    /**买方合同份数*/
    private Integer buyerhtfs;

    /**委托合同号*/
    private String wthth;

    /**付款期限1（YYYY-MM-DD）*/
    private String fkqx1;

    /**付款金额1（单位：元）*/
    private Double fkje1;

    /**付款期限2（YYYY-MM-DD）*/
    private String fkqx2;

    /**付款金额2（单位：元）*/
    private Double fkje2;

    /**付款期限3（YYYY-MM-DD）*/
    private String fkqx3;

    /**付款金额3（单位：元）*/
    private Double fkje3;

    /**首付款期限（YYYY-MM-DD）*/
    private String sfkqx;

    /**贷款期限（YYYY-MM-DD）*/
    private String dkqx;

    /**交易编号*/
    private String jybh;

    /**房屋基本情况其他*/
    private String fwjbqkqt;

    /**违约金2（单位：元）*/
    private Double wyj2;

    /**违约金3（单位：元）*/
    private Double wyj3;

    /**违约金其他*/
    private String wyjqt;

    /**付款方式其他*/
    private String fkfsqt;

    /**违约金4（单位：元）*/
    private Double wyj4;

    /**
     * 佣金约定方式其他
     */
    private String yjydfsqt;

    /**
     * 税费约定方式
     */
    private String sfydfsqt;

    /**
     * 税费承担说明
     */
    private String sfcdsm;

    /**
     * 乙方约定共有份额
     */
    private String yfydgyfe;

    /**
     * 是否贷款
     */
    private String sfdk;

    /**
     * 是否查封
     */
    private String sfcf;

    /**
     * 出卖人名称
     */
    private String cmr;

    /**
     * 出卖人证件种类
     */
    private String cmrzjzl;

    /**
     * 出卖人证件号
     */
    private String cmrzjh;

    /**
     * 买受人名称
     */
    private String msrmc;

    /**
     * 买受人证件种类
     */
    private String msrzjzl;

    /**
     * 买受人证件号
     */
    private String msrzjh;

    /**
     * 买受人联系地址
     */
    private String msrlxdz;

    /**
     * 买受人联系电话
     */
    private String msrlxdh;

    /**
     * 违约金比例
     */
    private String wyjbl;

    /**
     * 资金监管办理时间（天）
     */
    private String zjjgblsj;

    /**
     * 权属转移登记时间（天）
     */
    private String qszydjsj;

    /**
     * 配套设施过户时间（天）
     */
    private String ptssghsj;

    /**
     * 户口迁出时间（天）
     */
    private String hkqcsj;

    /**
     * 一次性付款日期（YYYY-MM-DD）
     */
    private String ycxfkrq;

    /**
     * 自筹余款期限（YYYY-MM-DD）
     */
    private String zcykqx;

    /**
     * 合同信息新增修改流程id
     */
    private String htlcid;

    /**
     * 合同备案业务流水号
     */
    private String htbaywlsh;


    /**
     *资金监管协议编号
     */
    private String zjjgxybh;

    /**
     * 资金监管业务流水号
     */
    private String zjjgywls;

    /**
     * 免监管申请 免除类型
     * 01：共有人之间份额转让
     * 02：直系亲属之间转让
     * 03：国有资产的房屋在产交所挂牌交易的
     * 04：其他不具备资金监管条件的情形
     * 05：承购出售双方有一方是单位的
     */
    private String mclx;
    /**
     * 合同余款
     */
    private String htyk;
    /**
     * 转让份额约定
     */
    private String zrfeyd;
    /**
     * 转让份额约定其他
     */
    private String zrfeydqt;
    /**
     * 房屋户籍迁出日期
     */
    private String hjqcrq;
    /**
     * 监管模式
     */
    private String jgms;
    /**
     * 不监管金额
     */
    private Double bjgje;

}

==> hlw-core-0.0.2-20250422.075438-9-sources.jar: cn/gtmap/hlw/core/model/GxYySqxxHtxx.java <==
package cn.gtmap.hlw.core.model;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;


/**
 * (GxYySqxxHtxx)表实体类BO
 *
 * @author makejava
 * @since 2023-05-31 14:14:45
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class GxYySqxxHtxx implements Serializable {
    private static final long serialVersionUID = 7664420771347555104L;
    /**
     * 申请id
     */
    private String sqid;

    /**
     * 受理编号
     */
    private String slbh;

    /**
     * 交易价格
     */
    private Double jyjg;

    /**
     * 付款方式
     */
    private String fkfs;

    /**
     * 首付款
     */
    private Double sfk;

    /**
     * 贷款种类
     */
    private String dkzl;

    /**
     * 申请贷款
     */
    private Double sqdk;

    /**
     * 是否通过代理
     */
    private String sftgdl;

    /**
     * 是否进行资金监管
     */
    private String sfzjjg;

    /**
     * 监管金额
     */
    private Double jgje;

    /**
     * 交付方式
     */
    private String jffs;

    private String jfqx;

    /**
     * 税费承担
     */
    private String sfcd;

    /**
     * 付款截至日期（YYYY-MM-DD）
     */
    private String fkjzrq;

    private String htqdrq;

    /**
     * 是否普通住房（0 否 1 是 ）
     */
    private String sfptzf;

    /**
     * 合同金额
     */
    private Double htje;

    /**
     * 单价
     */
    private Double dj;

    /**
     * 交易方式代码
     */
    private String jyfsdm;

    /**
     * 房屋交付日期（YYYY-MM-DD)
     */
    private String fwjfrq;

    /**
     * 不动产项目名称
     */
    private String xmmc;

    /**
     * 备案日期
     */
    private String barq;

    /**
     * 定金
     */
    private String yhdj;

    /**
     * 商贷金额
     */
    private String yhsdje;

    /**
     * 公积金贷款金额
     */
    private String yhgjjdkje;

    /**
     * 合同总额
     */
    private Double htze;

    /**
     * 备案状态代码（1：已备案0：未备案）
     */
    private String baztdm;

    /**
     * 成交价是否含税   0 否 1 是
     */
    private String cjjsfhs;

    /**
     * 房产证发证时间
     */
    private String fczfzsj;

    /**
     * 上次交易登记时间
     */
    private String scjydjsj;

    /**
     * 不含增值税金额
     */
    private Double bhzzsje;

    /**
     * 含增值税金额
     */
    private Double hzzsje;

    /**
     * 增值税金额
     */
    private Double zzsje;

    /**
     * 交易份额
     */
    private Double jyfe;

    /**
     * 监管编号
     */
    private String jgbh;

    /**
     * 合同坐落
     */
    private String htzl;

    /**
     * 合同义务人名称
     */
    private String htywrmc;

    /**
     * 其他约定事项
     */
    private String qtydsx;

    /**
     * 贷款银行
     */
    private String dkyh;

    /**
     * 合同约定登记时间
     */
    private String htyddjsj;

    /**
     * 人才劵金额
     */
    private String rcqje;

    /**
     * 违约金金额
     */
    private String wyjje;

    /**
     * 产籍号
     */
    private String fccjh;

    /**
     * 房地产交易时间（YYYY-MM-DD）
     */
    private String fdcjysj;

    /**
     * 签约类型（0：线上签订 1：线下签订）
     */
    private String qylx;

    /**
     * 是否签署（0：无合同 1：有合同）
     */
    private String sfqs;

    /**
     * 是否交房即发证（1：是，0：否）
     */
    private String sfjfjfz;

    /**
     * 交房即发证备注
     */
    private String jfjfzbz;

    /**
     * 交易合同id（交易返回htid）
     */
    private String jyhtid;

    /**
     * 自付款金额（单位：元）
     */
    private Double zfkje;

    /**
     * 其他款项金额（单位：元）
     */
    private Double qtkxje;

    /**
     * 付款金额（单位：元）
     */
    private Double fkje;

    /**
     * 付款期数
     */
    private Integer fkqs;

    /**
     * 约定登记日期
     */
    private String yddjrq;

    /**
     * 土地处理方式（zd_type表对照）
     */
    private String tdclfs;

    /**
     * 土地处理方式其他
     */
    private String tdclfsjqt;

    /**
     * 税费约定方式（zd_type表对照）
     */
    private String sfydfs;

    /**
     * 佣金约定方式（zd_type表对照）
     */
    private String yjydfs;

    /**
     * 争议解决方式（zd_type表对照）
     */
    private String zyjjfs;

    /**
     * 合同份数
     */
    private Integer htfs;

    /**
     * 卖方合同份数
     */
    private Integer salerhtfs;

    /**
     * 买方合同份数
     */
    private Integer buyerhtfs;

    /**
     * 委托合同号
     */
    private String wthth;

    /**
     * 付款期限1（YYYY-MM-DD）
     */
    private String fkqx1;

    /**
     * 付款金额1（单位：元）
     */
    private Double fkje1;

    /**
     * 付款期限2（YYYY-MM-DD）
     */
    private String fkqx2;

    /**
     * 付款金额2（单位：元）
     */
    private Double fkje2;

    /**
     * 付款期限3（YYYY-MM-DD）
     */
    private String fkqx3;

    /**
     * 付款金额3（单位：元）
     */
    private Double fkje3;

    /**
     * 首付款期限（YYYY-MM-DD）
     */
    private String sfkqx;

    /**
     * 贷款期限（YYYY-MM-DD）
     */
    private String dkqx;

    /**
     * 交易编号
     */
    private String jybh;

    /**
     * 房屋基本情况其他
     */
    private String fwjbqkqt;

    /**
     * 违约金2（单位：元）
     */
    private Double wyj2;

    /**
     * 违约金3（单位：元）
     */
    private Double wyj3;

    /**
     * 违约金其他
     */
    private String wyjqt;

    /**
     * 付款方式其他
     */
    private String fkfsqt;

    /**
     * 违约金4（单位：元）
     */
    private Double wyj4;

    /**
     * 佣金约定方式其他
     */
    private String yjydfsqt;

    /**
     * 税费约定方式
     */
    private String sfydfsqt;

    /**
     * 税费承担说明
     */
    private String sfcdsm;

    /**
     * 乙方约定共有份额
     */
    private String yfydgyfe;

    /**
     * 是否贷款
     */
    private String sfdk;

    /**
     * 是否查封
     */
    private String sfcf;

    /**
     * 出卖人名称
     */
    private String cmr;

    /**
     * 出卖人证件种类
     */
    private String cmrzjzl;

    /**
     * 出卖人证件号
     */
    private String cmrzjh;

    /**
     * 买受人名称
     */
    private String msrmc;

    /**
     * 买受人证件种类
     */
    private String msrzjzl;

    /**
     * 买受人证件号
     */
    private String msrzjh;

    /**
     * 买受人联系地址
     */
    private String msrlxdz;

    /**
     * 买受人联系电话
     */
    private String msrlxdh;

    /**
     * 违约金比例
     */
    private String wyjbl;

    /**
     * 资金监管办理时间（天）
     */
    private String zjjgblsj;

    /**
     * 权属转移登记时间（天）
     */
    private String qszydjsj;

    /**
     * 配套设施过户时间（天）
     */
    private String ptssghsj;

    /**
     * 户口迁出时间（天）
     */
    private String hkqcsj;

    /**
     * 一次性付款日期（YYYY-MM-DD）
     */
    private String ycxfkrq;

    /**
     * 自筹余款期限（YYYY-MM-DD）
     */
    private String zcykqx;

    /**
     * 合同信息新增修改流程id
     */
    private String htlcid;

    /**
     * 合同备案业务流水号
     */
    private String htbaywlsh;


    /**
     * 资金监管协议编号
     */
    private String zjjgxybh;

    /**
     * 资金监管业务流水号
     */
    private String zjjgywls;

    /**
     * 免监管申请 免除类型
     * 01：共有人之间份额转让
     * 02：直系亲属之间转让
     * 03：国有资产的房屋在产交所挂牌交易的
     * 04：其他不具备资金监管条件的情形
     * 05：承购出售双方有一方是单位的
     */
    private String mclx;
    /**
     * 合同余款
     */
    private String htyk;
    /**
     * 转让份额约定
     */
    private String zrfeyd;
    /**
     * 转让份额约定其他
     */
    private String zrfeydqt;
    /**
     * 房屋户籍迁出日期
     */
    private String hjqcrq;
    /**
     * 监管模式
     */
    private String jgms;
    /**
     * 不监管金额
     */
    private Double bjgje;


    //镇江交易合同生成附加开始

    /**
     * 房屋情况说明
     */
    private String fwqksm;

    /**
     * 是否出租
     */
    private String sfcz;
    /**
     * 出租处理方式
     */
    private String czclfs;
    /**
     * 出租处理方式说明
     */
    private String czclfssm;
    /**
     * 附属设施及装潢金额
     */
    private String fsssjzhje;
    /**
     * 交易定金
     */
    private String jydj;
    /**
     * 是否已缴纳物业维修基金
     */
    private String sfywywxjj;
    /**
     * 交易执行方式
     */
    private String jyzxfs;
    /**
     * 托管银行
     */
    private String tgyh;
    /**
     * 付款期限
     */
    private String fkqx;
    /**
     * 房款付清方式
     */
    private String fkfqfs;
    /**
     * 付款方式说明
     */
    private String fkfssm;
    /**
     * 房屋交付方式
     */
    private String fwjffs;
    /**
     * 房屋交付方式说明
     */
    private String fwjffssm;
    /**
     * 税、费缴纳约定
     */
    private String sfjnyd;
    /**
     * 甲方反悔退回双倍定金期限
     */
    private String jffhtsbdjqx;
    /**
     * 未按期付清房款或交付房屋处理方式
     */
    private String yqclfs;
    /**
     * 逾期每日缴纳金额
     */
    private String yqmrje;
    /**
     * 逾期可解约期限
     */
    private String yqkjyqx;
    /**
     * 逾期违约金千分比
     */
    private String yqwyjqfb;

    /**
     * 未按期付清房款获取交付房屋处理方式说明
     */
    private String yqclfssm;
    /**
     * 逾期违约金千分比
     */
    private String yqwyjqfb2;

    /**
     * 悔约超违约金约定
     */
    private String hycwyjyd;
    /**
     * 发生争执协商未果处理方式
     */
    private String fszzxswgclfs;
    /**
     * 交易报告单领取委托人
     */
    private String jybgdlqwtr;
    /**
     * 其他事项约定
     */
    private String qtsxyd;
    /**
     * 附加条款
     */
    private String fjtk;
    //镇江交易合同生成附加结束

    /**
     * 其他参数
     */
    private String qtcs;
}
